EigenTask

pub trait EigenTask:
    Clone
    + Send
    + Sync
    + 'static {
    // Required methods
    fn task_index(&self) -> TaskIndex;
    fn created_block(&self) -> u32;
    fn quorum_numbers(&self) -> Vec<u8> ;
    fn quorum_threshold_percentage(&self) -> u8;
    fn encode(&self) -> Vec<u8> ;

    // Provided method
    fn digest(&self) -> FixedBytes<32> { ... }
}
Trait for a generic EigenLayer task

Required Methods

fn task_index(&self) -> TaskIndex

Get the task index/ID

fn created_block(&self) -> u32

Get the block at which the task was created

fn quorum_numbers(&self) -> Vec<u8>

Get the quorum numbers this task is associated with

fn quorum_threshold_percentage(&self) -> u8

Get the quorum threshold percentage required for this task

fn encode(&self) -> Vec<u8>

Encode the task to bytes for hashing

Provided Methods

fn digest(&self) -> FixedBytes<32>

Create a digest of the task

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors